package com.miaxis.gan.service.impl;

import java.util.*;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.common.config.ShiShenConfig;
import com.miaxis.common.utils.DateUtils;
import com.miaxis.disease.domain.DiseasePart;
import com.miaxis.disease.dto.DiseasePartDto;
import com.miaxis.disease.mapper.DiseasePartMapper;
import com.miaxis.gan.dto.GanZhiDto;
import com.miaxis.gan.dto.LiuNianDto;
import com.miaxis.gan.vo.GanZhiKongWangVo;
import com.miaxis.gan.vo.GanZhiNaYinVo;
import com.miaxis.gan.vo.GanZhiRowVo;
import com.miaxis.ge.domain.GeJu;
import com.miaxis.ge.mapper.GeJuMapper;
import com.miaxis.jie.mapper.JieQiMapper;
import com.miaxis.jie.vo.JieQiVo;
import com.miaxis.number.domain.NumberYun;
import com.miaxis.number.mapper.NumberYunMapper;
import com.nlf.calendar.Lunar;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.apache.commons.lang3.StringUtils;
import com.miaxis.gan.mapper.GanZhiMapper;
import com.miaxis.gan.domain.GanZhi;
import com.miaxis.gan.service.IGanZhiService;

/**
 * 天干地支Service业务层处理
 *
 * @author miaxis
 * @date 2023-11-16
 */
@Service
public class GanZhiServiceImpl extends ServiceImpl<GanZhiMapper, GanZhi> implements IGanZhiService {
    @Autowired
    private GanZhiMapper ganZhiMapper;

    @Autowired
    private NumberYunMapper numberYunMapper;

    @Autowired
    private DiseasePartMapper diseasePartMapper;

    @Autowired
    private ShiShenConfig shiShenConfig;

    @Autowired
    private JieQiMapper jieQiMapper;

    @Autowired
    private GeJuMapper geJuMapper;



    /**
     * 查询天干地支列表
     *
     * @param ganZhi 天干地支
     * @return 天干地支
     */
    @Override
    public List<GanZhi> selectGanZhiList(GanZhi ganZhi) {
        return ganZhiMapper.selectGanZhiList(ganZhi);
    }

    @Override
    public List<GanZhiRowVo> selectGanZhiRowVoList(GanZhiDto ganZhiDto) {

        List<GanZhiRowVo> list = this.getGanZhiRowVoList(ganZhiDto);
        if (ganZhiDto.getSex() == 1) {
            list.get(4).setShiShen1("元男");
        } else if (ganZhiDto.getSex() == 2) {
            list.get(4).setShiShen1("元女");
        }

        /*-----------------------十神 开始-------------------*/
        for (int i = 0; i < list.size(); i++) {

            if ((i == 0 || i == 2 || i == 6) && i != 4) {

                String zhengYin = shiShenConfig.getZhengYin().get(list.get(i).getName()); //正印
                String shiShen = shiShenConfig.getShiShen().get(list.get(i).getName());  //食神
                String zhengGuan = shiShenConfig.getZhengGuan().get(list.get(i).getName()); //正官
                String zhengCai = shiShenConfig.getZhengCai().get(list.get(i).getName()); //正财
                String qiSha = shiShenConfig.getQiSha().get(list.get(i).getName());  //七杀
                String pianYin = shiShenConfig.getPianYin().get(list.get(i).getName()); //偏印
                String shangGuan = shiShenConfig.getShangGuan().get(list.get(i).getName()); // 伤官
                String jieCai = shiShenConfig.getJieCai().get(list.get(i).getName()); // 劫财
                String biJian = shiShenConfig.getBiJian().get(list.get(i).getName()); // 比肩
                String pianCai = shiShenConfig.getPianCai().get(list.get(i).getName()); // 偏财

                if (list.get(4).getName().equals(zhengYin)) { //比对出正印
                    list.get(i).setShiShen1("正印");
                }
                if (list.get(4).getName().equals(shiShen)) { //比对出食神
                    list.get(i).setShiShen1("食神");
                }
                if (list.get(4).getName().equals(zhengGuan)) { //比对出正官
                    list.get(i).setShiShen1("正官");
                }
                if (list.get(4).getName().equals(zhengCai)) { //比对出正财
                    list.get(i).setShiShen1("正财");
                }
                if (list.get(4).getName().equals(qiSha)) { //比对出七杀
                    list.get(i).setShiShen1("七杀");
                }
                if (list.get(4).getName().equals(pianYin)) { //比对出偏印
                    list.get(i).setShiShen1("偏印");
                }
                if (list.get(4).getName().equals(shangGuan)) { //比对出伤官
                    list.get(i).setShiShen1("伤官");
                }
                if (list.get(4).getName().equals(jieCai)) { //比对出劫财
                    list.get(i).setShiShen1("劫财");
                }
                if (list.get(4).getName().equals(biJian)) { //比对出比肩
                    list.get(i).setShiShen1("比肩");
                }
                if (list.get(4).getName().equals(pianCai)) { //比对出偏财
                    list.get(i).setShiShen1("偏财");
                }

            }

            if ((i == 1 || i == 3 || i == 5 || i == 7) && i != 4) {   //地支

                String benQi = shiShenConfig.getBenQi().get(list.get(i).getName());    //戊
                String zhongQi = shiShenConfig.getZhongQi().get(list.get(i).getName()); //乙
                String yuQi = shiShenConfig.getYuQi().get(list.get(i).getName());   //癸

                /*------------------------正印--------------------------*/
                String zhengYinBenQi = (benQi != null) ? shiShenConfig.getZhengYin().get(benQi) : null; //正印本气
                String zhengYinZhongQi = (zhongQi != null) ? shiShenConfig.getZhengYin().get(zhongQi) : null; //正印中余
                String zhengYinYuQi = (yuQi != null) ? shiShenConfig.getZhengYin().get(yuQi) : null; //正印余气

                if (StringUtils.isNotEmpty(zhengYinBenQi) && list.get(4).getName().equals(zhengYinBenQi)) { //比对出正印
                    list.get(i).setShiShen1(benQi + "(正印)");
                }
                if (StringUtils.isNotEmpty(zhengYinZhongQi) && list.get(4).getName().equals(zhengYinZhongQi)) { //比对出正印
                    list.get(i).setShiShen2(zhongQi + "(正印)");
                }
                if (StringUtils.isNotEmpty(zhengYinYuQi) && list.get(4).getName().equals(zhengYinYuQi)) { //比对出正印
                    list.get(i).setShiShen3(yuQi + "(正印)");
                }


                /*------------------------食神-----------------------------*/
                String shiShenBenQi = (benQi != null) ? shiShenConfig.getShiShen().get(benQi) : null; //食神本气
                String shiShenZhongQi = (zhongQi != null) ? shiShenConfig.getShiShen().get(zhongQi) : null; //食神中气
                String shiShenYuQi = (yuQi != null) ? shiShenConfig.getShiShen().get(yuQi) : null; //食神余气

                if (StringUtils.isNotEmpty(shiShenBenQi) && list.get(4).getName().equals(shiShenBenQi)) { //比对出食神
                    list.get(i).setShiShen1(benQi + "(食神)");
                }
                if (StringUtils.isNotEmpty(shiShenZhongQi) && list.get(4).getName().equals(shiShenZhongQi)) { //比对出食神
                    list.get(i).setShiShen2(zhongQi + "(食神)");
                }
                if (StringUtils.isNotEmpty(shiShenYuQi) && list.get(4).getName().equals(shiShenYuQi)) { //比对出食神
                    list.get(i).setShiShen3(yuQi + "(食神)");
                }

                /*------------------------正官-----------------------------*/
                String zhengGuanBenQi = (benQi != null) ? shiShenConfig.getZhengGuan().get(benQi) : null; //正官本气
                String zhengGuanZhongQi = (zhongQi != null) ? shiShenConfig.getZhengGuan().get(zhongQi) : null; //正官中气
                String zhengGuanYuQi = (yuQi != null) ? shiShenConfig.getZhengGuan().get(yuQi) : null; //正官 余气

                if (StringUtils.isNotEmpty(zhengGuanBenQi) && list.get(4).getName().equals(zhengGuanBenQi)) { //比对出正官
                    list.get(i).setShiShen1(benQi + "(正官)");
                }
                if (StringUtils.isNotEmpty(zhengGuanZhongQi) && list.get(4).getName().equals(zhengGuanZhongQi)) { //比对出正官
                    list.get(i).setShiShen2(zhongQi + "(正官)");
                }
                if (StringUtils.isNotEmpty(zhengGuanYuQi) && list.get(4).getName().equals(zhengGuanYuQi)) { //比对出正官
                    list.get(i).setShiShen3(yuQi + "(正官)");
                }

                /*------------------------正财-----------------------------*/
                String zhengCaiBenQi = (benQi != null) ? shiShenConfig.getZhengCai().get(benQi) : null; //正财本气
                String zhengCaiZhongQi = (zhongQi != null) ? shiShenConfig.getZhengCai().get(zhongQi) : null; //正财中气
                String zhengCaiYuQi = (yuQi != null) ? shiShenConfig.getZhengCai().get(yuQi) : null; //正财余气

                if (StringUtils.isNotEmpty(zhengCaiBenQi) && list.get(4).getName().equals(zhengCaiBenQi)) { //比对出正财
                    list.get(i).setShiShen1(benQi + "(正财)");
                }
                if (StringUtils.isNotEmpty(zhengCaiZhongQi) && list.get(4).getName().equals(zhengCaiZhongQi)) { //比对出正财
                    list.get(i).setShiShen2(zhongQi + "(正财)");
                }
                if (StringUtils.isNotEmpty(zhengCaiYuQi) && list.get(4).getName().equals(zhengCaiYuQi)) { //比对出正财
                    list.get(i).setShiShen3(yuQi + "(正财)");
                }


                /*------------------------七杀-----------------------------*/
                String qiShaBenQi = (benQi != null) ? shiShenConfig.getQiSha().get(benQi) : null; //七杀本气
                String qiShaZhongQi = (zhongQi != null) ? shiShenConfig.getQiSha().get(zhongQi) : null; //七杀中气
                String qiShaYuQi = (yuQi != null) ? shiShenConfig.getQiSha().get(yuQi) : null; //七杀余气

                if (StringUtils.isNotEmpty(qiShaBenQi) && list.get(4).getName().equals(qiShaBenQi)) { //比对出七杀
                    list.get(i).setShiShen1(benQi + "(七杀)");
                }
                if (StringUtils.isNotEmpty(qiShaZhongQi) && list.get(4).getName().equals(qiShaZhongQi)) { //比对出七杀
                    list.get(i).setShiShen2(zhongQi + "(七杀)");
                }
                if (StringUtils.isNotEmpty(qiShaYuQi) && list.get(4).getName().equals(qiShaYuQi)) { //比对出七杀
                    list.get(i).setShiShen3(yuQi + "(七杀)");
                }


                /*------------------------偏印-----------------------------*/
                String pianYinBenQi = (benQi != null) ? shiShenConfig.getPianYin().get(benQi) : null; //偏印本气
                String pianYinZhongQi = (zhongQi != null) ? shiShenConfig.getPianYin().get(zhongQi) : null; //偏印中气
                String pianYinYuQi = (yuQi != null) ? shiShenConfig.getPianYin().get(yuQi) : null; //偏印余气

                if (StringUtils.isNotEmpty(pianYinBenQi) && list.get(4).getName().equals(pianYinBenQi)) { //比对出七杀
                    list.get(i).setShiShen1(benQi + "(偏印)");
                }
                if (StringUtils.isNotEmpty(pianYinZhongQi) && list.get(4).getName().equals(pianYinZhongQi)) { //比对出七杀
                    list.get(i).setShiShen2(zhongQi + "(偏印)");
                }
                if (StringUtils.isNotEmpty(pianYinYuQi) && list.get(4).getName().equals(pianYinYuQi)) { //比对出七杀
                    list.get(i).setShiShen3(yuQi + "(偏印)");
                }

                /*------------------------伤官-----------------------------*/
                String shangGuanBenQi = (benQi != null) ? shiShenConfig.getShangGuan().get(benQi) : null; //伤官本气
                String shangGuanZhongQi = (zhongQi != null) ? shiShenConfig.getShangGuan().get(zhongQi) : null; //伤官中气
                String shangGuanYuQi = (yuQi != null) ? shiShenConfig.getShangGuan().get(yuQi) : null; //伤官余气

                if (StringUtils.isNotEmpty(shangGuanBenQi) && list.get(4).getName().equals(shangGuanBenQi)) { //比对出伤官
                    list.get(i).setShiShen1(benQi + "(伤官)");
                }
                if (StringUtils.isNotEmpty(shangGuanZhongQi) && list.get(4).getName().equals(shangGuanZhongQi)) { //比对出伤官
                    list.get(i).setShiShen2(zhongQi + "(伤官)");
                }
                if (StringUtils.isNotEmpty(shangGuanYuQi) && list.get(4).getName().equals(shangGuanYuQi)) { //比对出伤官
                    list.get(i).setShiShen3(yuQi + "(伤官)");
                }


                /*------------------------劫财-----------------------------*/
                String jieCaiBenQi = (benQi != null) ? shiShenConfig.getJieCai().get(benQi) : null; //劫财本气
                String jieCaiZhongQi = (zhongQi != null) ? shiShenConfig.getJieCai().get(zhongQi) : null; //劫财中气
                String jieCaiYuQi = (yuQi != null) ? shiShenConfig.getJieCai().get(yuQi) : null; //劫财余气

                if (StringUtils.isNotEmpty(jieCaiBenQi) && list.get(4).getName().equals(jieCaiBenQi)) { //比对出劫财
                    list.get(i).setShiShen1(benQi + "(劫财)");
                }
                if (StringUtils.isNotEmpty(jieCaiZhongQi) && list.get(4).getName().equals(jieCaiZhongQi)) { //比对出劫财
                    list.get(i).setShiShen2(zhongQi + "(劫财)");
                }
                if (StringUtils.isNotEmpty(jieCaiYuQi) && list.get(4).getName().equals(jieCaiYuQi)) { //比对出劫财
                    list.get(i).setShiShen3(yuQi + "(劫财)");
                }

                /*------------------------比肩-----------------------------*/
                String biJianBenQi = (benQi != null) ? shiShenConfig.getBiJian().get(benQi) : null; //比肩本气
                String biJianZhongQi = (zhongQi != null) ? shiShenConfig.getBiJian().get(zhongQi) : null; //比肩中气
                String biJianYuQi = (yuQi != null) ? shiShenConfig.getBiJian().get(yuQi) : null; //比肩余气

                if (StringUtils.isNotEmpty(biJianBenQi) && list.get(4).getName().equals(biJianBenQi)) {
                    list.get(i).setShiShen1(benQi + "(比肩)");
                }
                if (StringUtils.isNotEmpty(biJianZhongQi) && list.get(4).getName().equals(biJianZhongQi)) {
                    list.get(i).setShiShen2(zhongQi + "(比肩)");
                }
                if (StringUtils.isNotEmpty(biJianYuQi) && list.get(4).getName().equals(biJianYuQi)) {
                    list.get(i).setShiShen3(yuQi + "(比肩)");
                }

                /*------------------------偏财-----------------------------*/
                String pianCaiBenQi = (benQi != null) ? shiShenConfig.getPianCai().get(benQi) : null; //偏财本气
                String pianCaiZhongQi = (zhongQi != null) ? shiShenConfig.getPianCai().get(zhongQi) : null; //偏财中气
                String pianCaiYuQi = (yuQi != null) ? shiShenConfig.getPianCai().get(yuQi) : null; //偏财余气

                if (StringUtils.isNotEmpty(pianCaiBenQi) && list.get(4).getName().equals(pianCaiBenQi)) { //比对出偏财
                    list.get(i).setShiShen1(benQi + "(偏财)");
                }
                if (StringUtils.isNotEmpty(pianCaiZhongQi) && list.get(4).getName().equals(pianCaiZhongQi)) { //比对出偏财
                    list.get(i).setShiShen2(zhongQi + "(偏财)");
                }
                if (StringUtils.isNotEmpty(pianCaiYuQi) && list.get(4).getName().equals(pianCaiYuQi)) { //比对出偏财
                    list.get(i).setShiShen3(yuQi + "(偏财)");
                }

            }


        }
        /*-----------------------十神 结束-------------------*/

        return list;
    }


    @Override
    public List<GanZhiNaYinVo> selectGanZhiNaYinList(GanZhiDto ganZhiDto) {

        String yearZhuNaYinKey = ganZhiDto.getYearGan() + ganZhiDto.getYearZhi();
        String monthZhuNaYinKey = ganZhiDto.getMonthGan() + ganZhiDto.getMonthZhi();
        String dayZhuNaYinKey = ganZhiDto.getDayGan() + ganZhiDto.getDayZhi();
        String timeZhuNaYinKey = ganZhiDto.getTimeGan() + ganZhiDto.getTimeZhi();

        String yearZhuNaYin = shiShenConfig.getNaYin().get(yearZhuNaYinKey);
        String monthZhuNaYin = shiShenConfig.getNaYin().get(monthZhuNaYinKey);
        String dayZhuNaYin = shiShenConfig.getNaYin().get(dayZhuNaYinKey);
        String timeZhuNaYin = shiShenConfig.getNaYin().get(timeZhuNaYinKey);

        GanZhiNaYinVo yearNaYinVo = new GanZhiNaYinVo();
        yearNaYinVo.setZhu("年");
        yearNaYinVo.setNaYin(yearZhuNaYin);
        GanZhiNaYinVo monthNaYinVo = new GanZhiNaYinVo();
        monthNaYinVo.setZhu("月");
        monthNaYinVo.setNaYin(monthZhuNaYin);
        GanZhiNaYinVo dayNaYinVo = new GanZhiNaYinVo();
        dayNaYinVo.setZhu("日");
        dayNaYinVo.setNaYin(dayZhuNaYin);
        GanZhiNaYinVo timeNaYinVo = new GanZhiNaYinVo();
        timeNaYinVo.setZhu("时");
        timeNaYinVo.setNaYin(timeZhuNaYin);

        List<GanZhiNaYinVo> list = new ArrayList<GanZhiNaYinVo>();
        list.add(yearNaYinVo);
        list.add(monthNaYinVo);
        list.add(dayNaYinVo);
        list.add(timeNaYinVo);
        return list;
    }


    @Override
    public List<GanZhiKongWangVo> selectGanZhiKongWangList(GanZhiDto ganZhiDto) {

        String yearZhuKongWangKey = ganZhiDto.getYearGan() + ganZhiDto.getYearZhi();
        String monthZhuKongWangKey = ganZhiDto.getMonthGan() + ganZhiDto.getMonthZhi();
        String dayZhuNaKongWangKey = ganZhiDto.getDayGan() + ganZhiDto.getDayZhi();
        String timeZhuNaKongWangKey = ganZhiDto.getTimeGan() + ganZhiDto.getTimeZhi();

        String yearZhuKongWang = shiShenConfig.getKongWang().get(yearZhuKongWangKey);
        String monthZhuKongWang = shiShenConfig.getKongWang().get(monthZhuKongWangKey);
        String dayZhuKongWang = shiShenConfig.getKongWang().get(dayZhuNaKongWangKey);
        String timeZhuKongWang = shiShenConfig.getKongWang().get(timeZhuNaKongWangKey);

        GanZhiKongWangVo yearKongWangVo = new GanZhiKongWangVo();
        yearKongWangVo.setZhu("年");
        yearKongWangVo.setKongWang(yearZhuKongWang);
        GanZhiKongWangVo monthKongWangVo = new GanZhiKongWangVo();
        monthKongWangVo.setZhu("月");
        monthKongWangVo.setKongWang(monthZhuKongWang);
        GanZhiKongWangVo dayKongWangVo = new GanZhiKongWangVo();
        dayKongWangVo.setZhu("日");
        dayKongWangVo.setKongWang(dayZhuKongWang);
        GanZhiKongWangVo timeKongWangVo = new GanZhiKongWangVo();
        timeKongWangVo.setZhu("时");
        timeKongWangVo.setKongWang(timeZhuKongWang);

        List<GanZhiKongWangVo> list = new ArrayList<GanZhiKongWangVo>();
        list.add(yearKongWangVo);
        list.add(monthKongWangVo);
        list.add(dayKongWangVo);
        list.add(timeKongWangVo);
        return list;
    }

    @Override
    public Map<String, Object> getRiYuanQr(GanZhiDto ganZhiDto) {
        /*-------------------日元身强身弱---------------------*/
        List<GanZhiRowVo> list = this.getGanZhiRowVoList(ganZhiDto);
        int yearGanQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(0).getFive());
        int yearZhiQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(1).getFive());
        int monthGanQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(2).getFive());
        int monthZhiQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(3).getFive());
        //     int dayGanQR = ShiShenConfig.generateRelationship(list.get(4).getFive(),list.get(4).getFive());
        int dayZhiQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(5).getFive());
        int timeGanQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(6).getFive());
        int timeZhiQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(7).getFive());

        int score = 0;
        if (yearGanQR > 0) {
            score += 8;
        }
        if (yearZhiQR > 0) {
            score += 4;
        }
        if (monthGanQR > 0) {
            score += 12;
        }
        if (monthZhiQR > 0) {
            score += 40;
        }
        if (dayZhiQR > 0) {
            score += 12;
        }
        if (timeGanQR > 0) {
            score += 12;
        }
        if (timeZhiQR > 0) {
            score += 12;
        }

        List<String> xiYong = null;
        String fiveQr = null;
        if (score > 50) {
            fiveQr = list.get(4).getFive() + "强";
            xiYong = shiShenConfig.getXiYong().get(fiveQr);
        } else {
            fiveQr = list.get(4).getFive() + "弱";
            xiYong = shiShenConfig.getXiYong().get(fiveQr);
        }
        String xi1 = xiYong.get(0);
        String xi2 = xiYong.get(1);

        Map<String, Integer> fiveCountMap = this.getGanZhiRowVoCount(ganZhiDto);
        int xi1Count = fiveCountMap.get(xi1);
        int xi2Count = fiveCountMap.get(xi2);

        if (xi1Count > 3) {
            xiYong.remove(xi1);
        }
        if (xi2Count > 3) {
            xiYong.remove(xi2);
        }

        System.out.println("喜用：" + xiYong);

        Map<String, Object> qr = new TreeMap<String, Object>();
        qr.put("score", score);
        qr.put("qr", fiveQr);
        qr.put("xiYong", xiYong);

        return qr;
    }


    @Override
    public List<DiseasePart> getJiBing(GanZhiDto ganZhiDto) {
        List<GanZhiRowVo> ganZhiRowVoList = this.selectGanZhiRowVoList(ganZhiDto);
        String sex = ganZhiRowVoList.get(4).getShiShen1();

        String gender = null;
        if ("元男".equals(sex)) {  //男性疾病
            sex = "1,3";
        } else if ("元女".equals(sex)) {  //女性疾病
            sex = "2,3";
        }

        List<String> partZ = new ArrayList<String>();
        List<String> partQ = new ArrayList<String>();




        /*--------------------------年柱---------------------------*/
        //天干 头
        String yearGanShiShen = ganZhiRowVoList.get(0).getShiShen1();
        if ("七杀".contains(yearGanShiShen)) { //存在七杀
            partZ.add("头");
        }
        if ("偏印".contains(yearGanShiShen)) { //存在七杀
            partQ.add("头");
        }
        //地支 脖子
        String yearZhiShiShen1 = ganZhiRowVoList.get(1).getShiShen1(); //脖子
        String yearZhiShiShen2 = ganZhiRowVoList.get(1).getShiShen2(); //脖子
        String yearZhiShiShen3 = ganZhiRowVoList.get(1).getShiShen3(); //脖子
        if (yearZhiShiShen1 != null && yearZhiShiShen1.contains("七杀")) { //存在七杀
            partZ.add("脖子");
        }
        if (yearZhiShiShen2 != null && yearZhiShiShen2.contains("七杀")) { //存在七杀
            partZ.add("脖子");
        }
        if (yearZhiShiShen3 != null && yearZhiShiShen3.contains("七杀")) { //存在七杀
            partZ.add("脖子");
        }
        if (yearZhiShiShen1 != null && yearZhiShiShen1.contains("偏印")) { //存在偏印
            partQ.add("脖子");
        }
        if (yearZhiShiShen2 != null && yearZhiShiShen2.contains("偏印")) { //存在偏印
            partQ.add("脖子");
        }
        if (yearZhiShiShen3 != null && yearZhiShiShen3.contains("偏印")) { //存在偏印
            partQ.add("脖子");
        }

        /*--------------------------月柱---------------------------*/

        //天干 胸部
        String monthGanShiShen = ganZhiRowVoList.get(2).getShiShen1();
        if (monthGanShiShen != null && monthGanShiShen.contains("七杀")) { //存在七杀
            partZ.add("胸部");
        }
        if (monthGanShiShen != null && monthGanShiShen.contains("偏印")) { //存在偏印
            partQ.add("胸部");
        }
        //地支 脖子
        String monthZhiShiShen1 = ganZhiRowVoList.get(3).getShiShen1();
        String monthZhiShiShen2 = ganZhiRowVoList.get(3).getShiShen2();
        String monthZhiShiShen3 = ganZhiRowVoList.get(3).getShiShen3();
        if (monthZhiShiShen1 != null && monthZhiShiShen1.contains("七杀")) { //存在七杀
            partZ.add("腹部");
        }
        if (monthZhiShiShen2 != null && monthZhiShiShen2.contains("七杀")) { //存在七杀
            partZ.add("腹部");
        }
        if (monthZhiShiShen3 != null && monthZhiShiShen3.contains("七杀")) { //存在七杀
            partZ.add("腹部");
        }
        if (monthZhiShiShen1 != null && monthZhiShiShen1.contains("偏印")) { //存在偏印
            partQ.add("腹部");
        }
        if (monthZhiShiShen2 != null && monthZhiShiShen2.contains("偏印")) { //存在偏印
            partQ.add("腹部");
        }
        if (monthZhiShiShen3 != null && monthZhiShiShen3.contains("偏印")) { //存在偏印
            partQ.add("腹部");
        }

        /*--------------------------日柱---------------------------*/
        //天干
        String dayGanShiShen = ganZhiRowVoList.get(4).getShiShen1();
        if (dayGanShiShen != null && "七杀".contains(dayGanShiShen)) { //存在七杀
            partZ.add("小腹");
        }
        if (dayGanShiShen != null && "偏印".contains(dayGanShiShen)) { //存在七杀
            partQ.add("小腹");
        }
        //地支 脖子
        String dayZhiShiShen1 = ganZhiRowVoList.get(5).getShiShen1();
        String dayZhiShiShen2 = ganZhiRowVoList.get(5).getShiShen2();
        String dayZhiShiShen3 = ganZhiRowVoList.get(5).getShiShen3();
        if (dayZhiShiShen1 != null && dayZhiShiShen1.contains("七杀")) { //存在七杀
            partZ.add("屁股");
        }
        if (dayZhiShiShen2 != null && dayZhiShiShen2.contains("七杀")) { //存在七杀
            partZ.add("屁股");
        }
        if (dayZhiShiShen3 != null && dayZhiShiShen3.contains("七杀")) { //存在七杀
            partZ.add("屁股");
        }
        if (dayZhiShiShen1 != null && dayZhiShiShen1.contains("偏印")) { //存在偏印
            partQ.add("屁股");
        }
        if (dayZhiShiShen2 != null && dayZhiShiShen2.contains("偏印")) { //存在偏印
            partQ.add("屁股");
        }
        if (dayZhiShiShen3 != null && dayZhiShiShen3.contains("偏印")) { //存在偏印
            partQ.add("屁股");
        }

        /*--------------------------时柱---------------------------*/
        //天干
        String timeGanShiShen = ganZhiRowVoList.get(6).getShiShen1();
        if (timeGanShiShen != null && timeGanShiShen.contains("七杀")) { //存在七杀
            partZ.add("小腹");
        }
        if (timeGanShiShen != null && timeGanShiShen.contains("偏印")) { //存在七杀
            partQ.add("小腹");
        }
        //地支 脖子
        String timeZhiShiShen1 = ganZhiRowVoList.get(7).getShiShen1();
        String timeZhiShiShen2 = ganZhiRowVoList.get(7).getShiShen2();
        String timeZhiShiShen3 = ganZhiRowVoList.get(7).getShiShen3();
        if (timeZhiShiShen1 != null && timeZhiShiShen1.contains("七杀")) { //存在七杀
            partZ.add("小腿");
        }
        if (timeZhiShiShen2 != null && timeZhiShiShen2.contains("七杀")) { //存在七杀
            partZ.add("小腿");
        }
        if (timeZhiShiShen3 != null && timeZhiShiShen3.contains("七杀")) { //存在七杀
            partZ.add("小腿");
        }
        if (timeZhiShiShen1 != null && timeZhiShiShen1.contains("偏印")) { //存在偏印
            partQ.add("小腿");
        }
        if (timeZhiShiShen2 != null && timeZhiShiShen2.contains("偏印")) { //存在偏印
            partQ.add("小腿");
        }
        if (timeZhiShiShen3 != null && timeZhiShiShen3.contains("偏印")) { //存在偏印
            partQ.add("小腿");
        }

        DiseasePartDto diseasePartQDto = new DiseasePartDto();
        diseasePartQDto.setSex(sex);
        diseasePartQDto.setDegree("轻症");
        diseasePartQDto.setParts(partQ);

        DiseasePartDto diseasePartZDto = new DiseasePartDto();
        diseasePartZDto.setSex(sex);
        diseasePartZDto.setDegree("严重");
        diseasePartZDto.setParts(partZ);

        List<DiseasePart> diseasePartQList = new ArrayList<DiseasePart>();
        List<DiseasePart> diseasePartZList = new ArrayList<DiseasePart>();
        List<DiseasePart> diseasePartAllList = new ArrayList<DiseasePart>();
        if (partQ.size() > 0) {
            diseasePartQList = diseasePartMapper.selectDiseasePartList(diseasePartQDto);
            diseasePartAllList.addAll(diseasePartQList);
        }

        if (partZ.size() > 0) {
            diseasePartZList = diseasePartMapper.selectDiseasePartList(diseasePartZDto);
            diseasePartAllList.addAll(diseasePartZList);
        }

        //五行得出疾病
        List<DiseasePart> fivePartList = new ArrayList<DiseasePart>();
        Map<String, Integer> fiveCount = this.getGanZhiRowVoCount(ganZhiDto);
        for (String key : fiveCount.keySet()) {
            int count = fiveCount.get(key);
            if (count >= 3) {
                List<String> partList = shiShenConfig.getFiveBuWei().get(key);
                DiseasePartDto fivePartDto = new DiseasePartDto();
                fivePartDto.setSex(sex);
                fivePartDto.setParts(partList);
                fivePartList = diseasePartMapper.selectDiseasePartList(fivePartDto);
                diseasePartAllList.addAll(fivePartList);
            }
        }

        return diseasePartAllList;
    }


    @Override
    public Map<String, Object> getNumberYun(Map<String, Object> qr) {

        List<String> numberList = new ArrayList<String>();
        List<String> xiYong = (List<String>) qr.get("xiYong");

        for (int i = 0; i < xiYong.size(); i++) {
            List<String> numList = shiShenConfig.getXiNumber().get(xiYong.get(i));
            numberList.addAll(numList);
        }

        List<NumberYun> numberYunList = numberYunMapper.getNumberYunByIds(numberList);


        //转字符串
        StringJoiner joiner = new StringJoiner(",");
        for (String number : numberList) {
            joiner.add(number);
        }
        String numbers = joiner.toString();


        Map<String, Object> resultMap = new TreeMap<String, Object>();
        resultMap.put("numberYuns", numbers);
        resultMap.put("numberYunList", numberYunList);

        return resultMap;
    }


    /**
     * 判断出生日期是否在节气内
     *
     * @return
     */
    @Override
    public GanZhiDto getDaYun(GanZhiDto ganZhiDto) {

        int daYun = 0;
        String tianGan = ganZhiDto.getYearGan();
        String yy = shiShenConfig.getTianGanYY().get(tianGan);

        if ("阳".equals(yy)) {
            if (ganZhiDto.getSex() == 1) {
                //顺行
                daYun = 1;
            } else if (ganZhiDto.getSex() == 2) {
                //逆行
                daYun = 2;
            }
        } else if ("阴".equals(yy)) {
            if (ganZhiDto.getSex() == 1) {
                //逆行
                daYun = 2;
            } else if (ganZhiDto.getSex() == 2) {
                //顺行
                daYun = 1;
            }
        }

        //判断当天是否是节气，如果在节前前， 月柱修改
        Date d1 = ganZhiDto.getBirthDay();
        Lunar lunar = Lunar.fromDate(d1);
        List<JieQiVo> list = jieQiMapper.selectJiiQiFb(d1);
        if (lunar.getJieQi() != null && !"".equals(lunar.getJieQi())) {
            //存在节气，如果第二个节气刚好当天相同
            if (list.get(1).getJieqiName().equals(lunar.getJieQi())) {
                //把月时间清空，再取一次月柱
                Calendar calendar = Calendar.getInstance();
                calendar.setTime(d1);
                calendar.add(Calendar.DAY_OF_MONTH, -1);
                Date d2 = calendar.getTime();
                //重新导入
                Lunar lunar2 = Lunar.fromDate(d2);
                ganZhiDto.setMonthGan(lunar2.getMonthGan());
                ganZhiDto.setMonthZhi(lunar2.getMonthZhi());
            }
        }
        System.out.println(ganZhiDto.getYearGan() + "," + ganZhiDto.getYearZhi() + "," + ganZhiDto.getMonthGan() + "," + ganZhiDto.getMonthZhi() + "," + ganZhiDto.getDayGan() + "," + ganZhiDto.getDayZhi() + "," + ganZhiDto.getTimeGan() + "," + ganZhiDto.getTimeZhi());

        if (daYun == 1) { //大运顺
            int daYunCount = 0;
            double dayDiff = Math.abs(list.get(1).getDaysDifference());
            double qiYunSuiDB = (dayDiff / 3);  //计算起运岁数
            int qiYunSui = (int) Math.ceil(qiYunSuiDB);
            System.out.println("大运顺起运岁数:" + qiYunSui);

            int year = lunar.getYear() + qiYunSui;
            System.out.println("大运顺起运岁年份数:" + year + "岁");

            String monthZhu = ganZhiDto.getMonthGan() + ganZhiDto.getMonthZhi();
            List<String> jiaziList = new ArrayList<String>(shiShenConfig.getLiushijiazi());

            List<Map<String, String>> daYunList = new ArrayList<Map<String, String>>();
            boolean flag = false;
            for (int i = 60; i < jiaziList.size(); i++) {
                if (flag) {
                    daYunCount++;
                    int daYunYear = year + (10 * daYunCount) - 10; //大运年份
                    int daYunSui = qiYunSui + (10 * daYunCount) - 10; // 大运岁数

                    Map<String, String> daYumMap = new TreeMap<String, String>();
                    daYumMap.put("daYunYear", daYunYear + "");
                    daYumMap.put("daYunSui", daYunSui + "岁");
                    daYumMap.put("daYunGanZhi", jiaziList.get(i));

                    daYunList.add(daYumMap);
                    if (daYunList.size() >= 10) {
                        break;
                    }
                    continue;
                }
                if (monthZhu.equals(jiaziList.get(i)) && flag == false) {
                    flag = true;
                }
            }
            ganZhiDto.setDaYunList(daYunList);
        } else if (daYun == 2) { //大运逆
            int daYunCount = 0;
            double dayDiff = Math.abs(list.get(0).getDaysDifference());
            double qiYunSuiDB = (dayDiff / 3);  //计算起运岁数
            int qiYunSui = (int) Math.ceil(qiYunSuiDB);
            System.out.println("大运顺起运岁数:" + qiYunSui);

            int year = lunar.getYear() + qiYunSui;
            System.out.println("大运顺起运岁年份数:" + year + "岁");

            String monthZhu = ganZhiDto.getMonthGan() + ganZhiDto.getMonthZhi();
            List<String> jiaziList = new ArrayList<String>(shiShenConfig.getLiushijiazi());
            List<Map<String, String>> daYunList = new ArrayList<Map<String, String>>();
            boolean flag = false;
            for (int i = 119; i >= 0; i--) {
                if (flag) {
                    daYunCount++;
                    int daYunYear = year + (10 * daYunCount) - 10; //大运年份
                    int daYunSui = qiYunSui + (10 * daYunCount) - 10; // 大运岁数
                    Map<String, String> daYumMap = new TreeMap<String, String>();
                    daYumMap.put("daYunYear", daYunYear + "");
                    daYumMap.put("daYunSui", daYunSui + "岁");
                    daYumMap.put("daYunGanZhi", jiaziList.get(i));
                    daYunList.add(daYumMap);
                    if (daYunList.size() >= 9) {
                        break;
                    }
                    continue;
                }
                if (monthZhu.equals(jiaziList.get(i)) && flag == false) {
                    flag = true;
                }
            }
            ganZhiDto.setDaYunList(daYunList);
        }
        return ganZhiDto;
    }

    @Override
    public List<Map<String, String>> getLiuNian(LiuNianDto linNianDto) {
        //yyyy-MM-dd HH:mm:ss
        List<Map<String, String>> liuNianList = new ArrayList<Map<String, String>>();

        int year = 0;
        for (int i = 0; i < 10; i++) {
            year = linNianDto.getYear() + i;
            Map<String, String> liuNianMap = new TreeMap<String, String>();
            String date = year + "-03-01 01:00:00";
            Lunar lunar = Lunar.fromDate(DateUtils.parseDate(date));
            liuNianMap.put("liuNianYear", year + "");
            liuNianMap.put("liuNianSui", linNianDto.getQiYunOld() + i + "岁");
            liuNianMap.put("liuNianGanZhi", lunar.getYearGan() + lunar.getYearZhi());
            liuNianList.add(liuNianMap);
        }
        return liuNianList;
    }


    /**
     * 干支组装
     *
     * @param ganZhiDto
     * @return
     */
    private List<GanZhiRowVo> getGanZhiRowVoList(GanZhiDto ganZhiDto) {

        String yearGanFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getYearGan());
        String yearZhiFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getYearZhi());
        String monthGanFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getMonthGan());
        String monthZhiFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getMonthZhi());
        String dayGanFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getDayGan());
        String dayZhiFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getDayZhi());
        String timeGanFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getTimeGan());
        String timeZhiFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getTimeZhi());


        String yearGanColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getYearGan());
        String yearZhiColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getYearZhi());
        String monthGanColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getMonthGan());
        String monthZhiColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getMonthZhi());
        String dayGanColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getDayGan());
        String dayZhiColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getDayZhi());
        String timeGanColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getTimeGan());
        String timeZhiColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getTimeZhi());

        GanZhiRowVo yearGan = new GanZhiRowVo();
        yearGan.setGongWei("年干");
        yearGan.setFive(yearGanFive);
        yearGan.setColor(yearGanColor);
        yearGan.setName(ganZhiDto.getYearGan());

        GanZhiRowVo yearZhi = new GanZhiRowVo();
        yearZhi.setGongWei("年支");
        yearZhi.setFive(yearZhiFive);
        yearZhi.setColor(yearZhiColor);
        yearZhi.setName(ganZhiDto.getYearZhi());

        GanZhiRowVo monthGan = new GanZhiRowVo();
        monthGan.setGongWei("月干");
        monthGan.setFive(monthGanFive);
        monthGan.setColor(monthGanColor);
        monthGan.setName(ganZhiDto.getMonthGan());


        GanZhiRowVo monthZhi = new GanZhiRowVo();
        monthZhi.setGongWei("月支");
        monthZhi.setFive(monthZhiFive);
        monthZhi.setColor(monthZhiColor);
        monthZhi.setName(ganZhiDto.getMonthZhi());

        GanZhiRowVo dayGan = new GanZhiRowVo();
        dayGan.setGongWei("日干");
        dayGan.setFive(dayGanFive);
        dayGan.setColor(dayGanColor);
        dayGan.setName(ganZhiDto.getDayGan());


        GanZhiRowVo dayZhi = new GanZhiRowVo();
        dayZhi.setGongWei("日支");
        dayZhi.setFive(dayZhiFive);
        dayZhi.setColor(dayZhiColor);
        dayZhi.setName(ganZhiDto.getDayZhi());

        GanZhiRowVo timeGan = new GanZhiRowVo();
        timeGan.setGongWei("时干");
        timeGan.setFive(timeGanFive);
        timeGan.setColor(timeGanColor);
        timeGan.setName(ganZhiDto.getTimeGan());

        GanZhiRowVo timeZhi = new GanZhiRowVo();
        timeZhi.setGongWei("时支");
        timeZhi.setFive(timeZhiFive);
        timeZhi.setColor(timeZhiColor);
        timeZhi.setName(ganZhiDto.getDayZhi());

        List<GanZhiRowVo> list = new ArrayList<GanZhiRowVo>();
        list.add(yearGan);
        list.add(yearZhi);
        list.add(monthGan);
        list.add(monthZhi);
        list.add(dayGan);
        list.add(dayZhi);
        list.add(timeGan);
        list.add(timeZhi);

        return list;
    }


    /**
     * 获取五行数量
     *
     * @param ganZhiDto
     * @return
     */
    @Override
    public Map<String, Integer> getGanZhiRowVoCount(GanZhiDto ganZhiDto) {

        Map<String, Integer> fiveCount = new TreeMap<String, Integer>();
        fiveCount.put("木", 0);
        fiveCount.put("火", 0);
        fiveCount.put("土", 0);
        fiveCount.put("金", 0);
        fiveCount.put("水", 0);

        List<GanZhiRowVo> list = this.getGanZhiRowVoList(ganZhiDto);
        for (int i = 0; i < list.size(); i++) {
            String five = list.get(i).getFive();
            Integer fiveC = fiveCount.get(five) + 1;
            fiveCount.put(five, fiveC);
        }
        return fiveCount;
    }


    /**
     * 潮湿平衡
     *
     * @param ganZhiDto
     * @return
     */
    @Override
    public Map<String, Object> getZaoShiCount(GanZhiDto ganZhiDto) {
        List<GanZhiRowVo> list = this.getGanZhiRowVoList(ganZhiDto);

        Map<String, Integer> fiveCount = this.getGanZhiRowVoCount(ganZhiDto);
        int huoCount = fiveCount.get("火");
        int shuiCount = fiveCount.get("水");

        for (int i = 1; i < list.size(); i += 2) {
            String five = list.get(i).getFive();
            if ("土".equals(five)) {
                if (huoCount > shuiCount) {
                    String name = list.get(i).getName();
                    if ("戌".equals(name) || "未".equals(name)) {
                        Integer fiveC = fiveCount.get("火") + 1;
                        fiveCount.put("火", fiveC);
                    }
                } else if (huoCount < shuiCount) {
                    String name = list.get(i).getName();
                    if ("辰".equals(name) || "丑".equals(name)) {
                        Integer fiveC = fiveCount.get("水") + 1;
                        fiveCount.put("水", fiveC);
                    }
                }
            }
        }
        fiveCount.remove("土");
        fiveCount.remove("金");
        fiveCount.remove("木");


        int huoCount2 = fiveCount.get("火");
        int shuiCoun2 = fiveCount.get("水");

        Map<String, Object> zaoShiMap = new TreeMap<String, Object>();
        zaoShiMap.putAll(fiveCount);


        if (huoCount2 - shuiCoun2 >= 2) {  //火过旺
            zaoShiMap.put("jieshi", "过于干燥，火特别多，性情比较暴躁，容易上火，内心上火容易产生无名火，容易被“点燃”生气，身体也容易上火。");
        } else if (huoCount2 - shuiCoun2 == 1) { //火轻微过旺
            zaoShiMap.put("jieshi", "偏干燥，火特别多，性情相对比较急躁。");
        } else if (huoCount2 - shuiCoun2 <= -2) {
            zaoShiMap.put("jieshi", "过于湿润，大便不成形，湿气太重了，比较会容易肚子，手脚冰凉，气血不活。");
        } else if (huoCount2 - shuiCoun2 == -1) {
            zaoShiMap.put("jieshi", "偏湿润，大便不成形，湿气较重，气血不活。");
        } else if (huoCount2 - shuiCoun2 == 0) {
            zaoShiMap.put("jieshi", "各个宫位，燥湿达到平衡。不会过湿，过燥。");
        }

        return zaoShiMap;
    }


    /**
     * 返回能量最强的天干
     *
     * @param ganZhiDto
     * @return 1 天干  2月干  3时干
     */
    @Override
    public int getMaxTianGan(GanZhiDto ganZhiDto) {
        /*-------------------能量最强天干---------------------*/
        List<GanZhiRowVo> list = this.getGanZhiRowVoList(ganZhiDto);

        //年干 得分
//        int yearGanQR = ShiShenConfig.generateRelationship(list.get(0).getFive(), list.get(0).getFive());
        int yearZhiQR1 = ShiShenConfig.generateRelationship(list.get(0).getFive(), list.get(1).getFive());
        int monthGanQR1 = ShiShenConfig.generateRelationship(list.get(0).getFive(), list.get(2).getFive());
        int monthZhiQR1 = ShiShenConfig.generateRelationship(list.get(0).getFive(), list.get(3).getFive());
        int dayGanQR1 = ShiShenConfig.generateRelationship(list.get(0).getFive(), list.get(4).getFive());
        int dayZhiQR1 = ShiShenConfig.generateRelationship(list.get(0).getFive(), list.get(5).getFive());
        int timeGanQR1 = ShiShenConfig.generateRelationship(list.get(0).getFive(), list.get(6).getFive());
        int timeZhiQR1 = ShiShenConfig.generateRelationship(list.get(0).getFive(), list.get(7).getFive());

        int yearGanScore = 0;
        if (yearZhiQR1 > 0) {
            yearGanScore += 12;
        }
        if (monthGanQR1 > 0) {
            yearGanScore += 12;
        }
        if (monthZhiQR1 > 0) {
            yearGanScore += 40;
        }
        if (dayGanQR1 > 0) {
            yearGanScore += 12;
        }
        if (dayZhiQR1 > 0) {
            yearGanScore += 12;
        }
        if (timeGanQR1 > 0) {
            yearGanScore += 8;
        }
        if (timeZhiQR1 > 0) {
            yearGanScore += 4;
        }

        /*-------------------能量最强天干---------------------*/

        //月干 得分
        int yearGanQR2 = ShiShenConfig.generateRelationship(list.get(2).getFive(), list.get(0).getFive());
        int yearZhiQR2 = ShiShenConfig.generateRelationship(list.get(2).getFive(), list.get(1).getFive());
//        int monthGanQR2 = ShiShenConfig.generateRelationship(list.get(2).getFive(), list.get(2).getFive());
        int monthZhiQR2 = ShiShenConfig.generateRelationship(list.get(2).getFive(), list.get(3).getFive());
        int dayGanQR2 = ShiShenConfig.generateRelationship(list.get(2).getFive(), list.get(4).getFive());
        int dayZhiQR2 = ShiShenConfig.generateRelationship(list.get(2).getFive(), list.get(5).getFive());
        int timeGanQR2 = ShiShenConfig.generateRelationship(list.get(2).getFive(), list.get(6).getFive());
        int timeZhiQR2 = ShiShenConfig.generateRelationship(list.get(2).getFive(), list.get(7).getFive());

        int monthGanScore = 0;
        if (yearGanQR2 > 0) {
            monthGanScore += 12;
        }
        if (yearZhiQR2 > 0) {
            monthGanScore += 12;
        }
        if (monthZhiQR2 > 0) {
            monthGanScore += 40;
        }
        if (dayGanQR2 > 0) {
            monthGanScore += 12;
        }
        if (dayZhiQR2 > 0) {
            monthGanScore += 12;
        }
        if (timeGanQR2 > 0) {
            monthGanScore += 8;
        }
        if (timeZhiQR2 > 0) {
            monthGanScore += 4;
        }


        //时干 得分
        int yearGanQR3 = ShiShenConfig.generateRelationship(list.get(6).getFive(), list.get(0).getFive());
        int yearZhiQR3 = ShiShenConfig.generateRelationship(list.get(6).getFive(), list.get(1).getFive());
        int monthGanQR3 = ShiShenConfig.generateRelationship(list.get(2).getFive(), list.get(2).getFive());
        int monthZhiQR3 = ShiShenConfig.generateRelationship(list.get(6).getFive(), list.get(3).getFive());
        int dayGanQR3 = ShiShenConfig.generateRelationship(list.get(6).getFive(), list.get(4).getFive());
        int dayZhiQR3 = ShiShenConfig.generateRelationship(list.get(6).getFive(), list.get(5).getFive());
        //int timeGanQR3 = ShiShenConfig.generateRelationship(list.get(6).getFive(), list.get(6).getFive());
        int timeZhiQR3 = ShiShenConfig.generateRelationship(list.get(6).getFive(), list.get(7).getFive());

        int timeGanScore = 0;
        if (yearGanQR3 > 0) {
            timeGanScore += 8;
        }
        if (yearZhiQR3 > 0) {
            timeGanScore += 4;
        }
        if (monthGanQR3 > 0) {
            timeGanScore += 40;
        }
        if (monthZhiQR3 > 0) {
            timeGanScore += 12;
        }
        if (dayGanQR3 > 0) {
            timeGanScore += 12;
        }
        if (dayZhiQR3 > 0) {
            timeGanScore += 12;
        }
        if (timeZhiQR3 > 0) {
            timeGanScore += 12;
        }
        int maxGan = ShiShenConfig.getMax(yearGanScore, monthGanScore, timeGanScore);
        ganZhiDto.setMaxGan(maxGan);
        return maxGan;
    }


    @Override
    public Map<String, String> getGeJu(List<GanZhiRowVo> list, int maxTianGan, String qr) {

        String yearGan = list.get(0).getShiShen1();
        String monthGan = list.get(2).getShiShen1();
        String timeGan = list.get(6).getShiShen1();

        String geju = null;

        if (list.get(3).getShiShen1() != null && yearGan.contains(list.get(3).getShiShen1())) { //月令十神1在 年干透出
            geju = list.get(3).getShiShen1();
        } else if (list.get(3).getShiShen1() != null && monthGan.contains(list.get(3).getShiShen1())) { //月令十神1在 月干透出
            geju = list.get(3).getShiShen1();
        } else if (list.get(3).getShiShen1() != null && timeGan.contains(list.get(3).getShiShen1())) { //月令十神1在 时干透出
            geju = list.get(3).getShiShen1();
        } else if (list.get(3).getShiShen2() != null && yearGan.contains(list.get(3).getShiShen2())) { //月令十神2在 年干透出
            geju = list.get(3).getShiShen2();
        } else if (list.get(3).getShiShen2() != null && monthGan.contains(list.get(3).getShiShen2())) { //月令十神2在 月干透出
            geju = list.get(3).getShiShen2();
        } else if (list.get(3).getShiShen2() != null && timeGan.contains(list.get(3).getShiShen2())) { //月令十神2在 时干透出
            geju = list.get(3).getShiShen2();
        } else if (list.get(3).getShiShen3() != null && yearGan.contains(list.get(3).getShiShen3())) { //月令十神3在 年干透出
            geju = list.get(3).getShiShen3();
        } else if (list.get(3).getShiShen3() != null && monthGan.contains(list.get(3).getShiShen3())) { //月令十神3在 月干透出
            geju = list.get(3).getShiShen3();
        } else if (list.get(3).getShiShen3() != null && timeGan.contains(list.get(3).getShiShen3())) { //月令十神3在 时干透出
            geju = list.get(3).getShiShen3();
        } else {
            geju = null;
        }

        if (geju == null) {
            if (maxTianGan == 1) {
                geju = yearGan;
            } else if (maxTianGan == 2) {
                geju = monthGan;
            } else if (maxTianGan == 3) {
                geju = timeGan;
            }
        }
        GeJu geJu = new GeJu();
        geJu.setShiShen(geju);
        if (qr.contains("强")) {
            geJu.setQr("3,1");
        } else if (qr.contains("弱")) {
            geJu.setQr("3,2");
        }

        String sex = list.get(4).getShiShen1();
        if ("元男".equals(sex)) {
            geJu.setSex("1,3");
        } else if ("元女".equals(sex)) {
            geJu.setSex("2,3");
        }

        List<GeJu> list2 = geJuMapper.selectGeJuList2(geJu);
        System.out.println(list2);
        return null;
    }


}